/* 	PostFixFilter.java
 * 
 * Created on: Oct 5, 2003
 * Created by: dennis
 * 
 * Copyright (c) 2003, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.brains2b.file;

import java.io.File;

import javax.swing.filechooser.FileFilter;

/** Implementation of the abstract FileFilter class
 * <p>This implementation only looks at the postfix of a file and will accept any
 * files which match the postfix. or is a directory
 * 
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [Oct 5, 2003]
 */
public class PostFixFilter extends FileFilter implements java.io.FileFilter {

	private String pattern;
	private String description;

	/**
	 * 
	 */
	public PostFixFilter(String pattern, String description) {
		super();
		this.pattern=checkPattern(pattern);
		if (description==null) {
			this.description=pattern;
		} else {
			this.description=description;
		}
	}

	/* (non-Javadoc)
	 * @see javax.swing.filechooser.FileFilter#accept(java.io.File)
	 */
	public boolean accept(File f) {
		if (f==null) return false;
		if (f.isDirectory()) return true;
		String name=f.getName();
		int idx=name.lastIndexOf(".");
		if (idx!=-1) {
			String postFix=name.substring(idx).toUpperCase();
			if (pattern.equals(postFix)) {
				return true;
			}
		}
		return false;
	}

	/* (non-Javadoc)
	 * @see javax.swing.filechooser.FileFilter#getDescription()
	 */
	public String getDescription() {
			return description;
	}

	private String checkPattern(String p) {
		if (p==null) {
			throw new NullPointerException("File filter requires a pattern");
		}
		int start=p.lastIndexOf(".");
		if (start!=-1) {
			p=p.substring(start);
		}
		p=p.toUpperCase();
		return p;
	}
	
	public String getExtention() {
		return pattern;
	}
}
