/* 	ExtInputMap.java
 *	Copyright (c) 2002-2004, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: Nov 06, 2002
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* @#History
 * [When]		[Who]					[What]
 * Oct 25, 2004	dennis@brains2b.nl		Do not add new action if actionmap's parent contains an action with
 * 										the same name		
 */
package org.brains2b.swingext.action;

import java.awt.event.ActionListener;

import javax.swing.ActionMap;
import javax.swing.ComponentInputMap;
import javax.swing.JComponent;
import javax.swing.KeyStroke;

/** 
 * Quick way to make a ComponentInputMap.
 * <p>As long as the JComponent implements ActionListener
 * the InputMap is filled and an ActionMap is created and
 * the actionCommandKey is send in the action to the 
 * {@link ActionListener#actionPerformed(java.awt.event.ActionEvent)}</p>
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.20 [06-07-2007]
 */
public class ExtInputMap extends ComponentInputMap {

	private ExtActionMap m_actionMap;

	/**
	 * Constructor for ExtInputMap.
	 */
	public ExtInputMap(JComponent parent) {
		super(parent);
        if ( !(parent instanceof ActionListener) ) {
            throw new IllegalArgumentException(
                    "ExtInputMap can only be used if the JComponent implements ActionListener");
        }
		m_actionMap=new ExtActionMap((ActionListener) parent);
	}

	/**
     * {@inheritDoc} 
	 */
	public void put(KeyStroke keyStroke, Object actionMapKey) {
	    if (m_actionMap.getParent()==null || m_actionMap.getParent().get(actionMapKey)==null) {
	        m_actionMap.put(actionMapKey,new DefaultAction(m_actionMap.getListener(),actionMapKey));
	    }
		super.put(keyStroke, actionMapKey);
	}

	
	/**
	 * get the actionMap created by this InputMap
	 * @return ActionMap
	 */
	public ActionMap getActionMap() {
		return m_actionMap;
	}

	
}
