/* 	IconFactory.java
 *	Copyright (c) 2004-2007, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: Apr 7, 2004
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* @#History
 * [When]		[Who]					[What]
 * 20-feb-2007	dennis@brains2b.nl      create Icon's for specific formats from original Images
 * TODO The icons should be soft referenced.		
*/
package org.brains2b.swingext.gui;

import java.awt.Image;
import java.util.HashMap;

import javax.swing.ImageIcon;

/** Creates and caches Icons from the given Resource location
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.20 [Feb 20, 2007]
 */
public final class IconFactory {
	public final static int ICON_16=16;
    public final static int ICON_32=16;
    public final static int ICON_48=48;
    
    private final static IconFactory factory=new IconFactory();
	
    /** the cache for the icons*/
	private HashMap icons;
    
    /**
     * Create a Singleton
     */
	private IconFactory() {
		super();
		icons=new HashMap();
	}
	
    /**
     * Create an ImageIcon from a path
     * <p>The icon is loaded from <code>getClass().getResource(URL)</code></p> 
     * @param path String, the path
     * @return ImageIcon, null if the Icon could not be loaded
     */
	public static final ImageIcon createIcon(String path) {
		return factory.loadIcon(path);
	}
    
    /**
     * Create an ImageIcon from a path with a specific size
     * <p>If the loaded ImageIcon is not the size defined the icon will
     * be scaled with <code>Image.SCALE_SMOOTH</code></p>
     * <p>The icon is loaded from <code>getClass().getResource(URL)</code></p> 
     * @param path String, the path
     * @param int, the size of the Icon. You can use one of the defaults ICON_16|ICON_32|ICON_48, but
     * any value will work. 
     * @return ImageIcon, null if the Icon could not be loaded
     */
    public static final ImageIcon createIcon(String path,int type) {
        ImageIcon icn =null;
        if ((icn=(ImageIcon) factory.icons.get(path+"!"+type))!=null) {
            return icn;
        } else {
            icn= factory.loadIcon(path);
            if (icn.getIconHeight()==type && icn.getIconHeight()==type) {
                return icn;
            }
            Image img= icn.getImage().getScaledInstance(type, type, Image.SCALE_SMOOTH);
            icn = new ImageIcon(img);
            factory.icons.put(path+"!"+type, icn);
            return icn;
        }
    }
	
	 
	private final ImageIcon loadIcon(String path) {
		ImageIcon icon=(ImageIcon) icons.get(path);
		if (icon==null) {
			icon=new ImageIcon(this.getClass().getResource(path));
			if (icon!=null) icons.put(path,icon);
			
		}
		return icon;
	}
}
