/* 	OptionalButton.java
 * 
 * Created on: 13-feb-03
 * Created by: Dennis Groenendijk
 * 
 * Copyright (c) 2003, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.brains2b.swingext.gui;

import javax.swing.Action;
import javax.swing.Icon;
import javax.swing.JButton;

/** OptionalButton is an extension of JButton to have a Button implementation
 *  that cannot get the focus, either by requesting it or through the FocusManager.
 * 	It will also not fire the Verify Input for the item that lost the focus, so it can
 *  be used to lookup information.
 * 
 *  <p>All the other JButton functionality is kept as is.
 *
 * 	<p><i>Note:</i>
 *  <UL>The reason for this class is two sided. 
 * 	<LI>The only way to set focustraversable is bij overwritting its getter.
 *  <LI>The only way to know if the VerifyInputWhenFocusTarget is set is to set it yourself
 *  </UL>(confused? you won't be after the next episode of ...)
 * @author  <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [13-02-2003]
 * @since 	 Framework 0.30a
 */
public class OptionalButton extends JButton {

    /**
     * Default Constructor for OptionalButton.
     */
    public OptionalButton() {
        super();
        init();
    }

    /**
     * Constructor for OptionalButton.
     * @param icon Icon, the icon to display for this button
     */
    public OptionalButton(Icon icon) {
        super(icon);
        init();
    }

    /**
     * Constructor for OptionalButton.
     * @param text String, the text to display for this button
     */
    public OptionalButton(String text) {
        super(text);
        init();
    }

    /**
     * Constructor for OptionalButton.
     * @param a Action, the Action this button will be based on.
     */
    public OptionalButton(Action a) {
        super(a);
        init();
    }

    /**
     * Constructor for OptionalButton.
     * @param text String, the text to display for this button
     * @param icon Icon, the icon to display for this button
     */
    public OptionalButton(String text, Icon icon) {
        super(text, icon);
        init();
    }

	/**
	 * Determines if this component can have the focus.
	 * Always return false
     */
    public boolean isFocusTraversable() {
        return false;
    }
    


	/**
	 * Determine if this component can request the focus.
	 * Always returns false
     * @see javax.swing.JComponent#isRequestFocusEnabled()
     */
    public boolean isRequestFocusEnabled() {
		return false;
    }
    

	/**
	 * set verify input on this button will always be left set to false
     * @see javax.swing.JComponent#setVerifyInputWhenFocusTarget(boolean)
     */
    public void setVerifyInputWhenFocusTarget(boolean flag) {
        
    }


	/** sets the initial values for this item */
	private void init() {
		super.setVerifyInputWhenFocusTarget(false);
		super.setRequestFocusEnabled(false);
        super.setFocusable(false);
	}
}
