/* 	StatusBar.java
 *  Copyright (c) 1999-2001, Dennis Groenendijk
 *	Copyright (c) 2002-2007, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* @#History
 * [When]		[Who]					[What]
 * Jul 6, 2007	dennis@brains2b.nl      Re-engineerd this class, added javadoc		
*/
package org.brains2b.swingext.gui;

import java.awt.Color;
import java.awt.GridLayout;

import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.border.BevelBorder;
import javax.swing.border.CompoundBorder;
import javax.swing.border.EmptyBorder;

public class StatusBar extends JPanel {
	
	public final static int EMPTY=0;
	public final static int CHANGED=1;
	public final static int NEW=2;
	
	private JLabel m_statusText;
	private JLabel m_fileStatus;
	private JLabel m_docStatus;
	private JLabel m_inputStatus;
	private JLabel m_infoRight;
	
	public StatusBar() {
		super();
		init();
	}
	
	private void init() {
		GridLayout gl=new GridLayout(1,2);
	
		setBorder(new EmptyBorder(2,0,1,0));
		setLayout(gl);
		
		CompoundBorder lowered=new CompoundBorder(new BevelBorder(BevelBorder.LOWERED),new EmptyBorder(0,3,0,3));	
		
		JPanel pnl2=new JPanel();
		pnl2.setLayout(gl);
		
		m_fileStatus=getLabel();
		m_fileStatus.setBorder(lowered);
		m_fileStatus.setName("fileStatus");
		pnl2.add(m_fileStatus);
			
		m_docStatus=getLabel();
		m_docStatus.setBorder(lowered);	
		m_docStatus.setHorizontalAlignment(JLabel.CENTER);
		m_docStatus.setName("documentStatus");
		pnl2.add(m_docStatus);
		
		m_inputStatus=getLabel();
		m_inputStatus.setText(" ");
		m_inputStatus.setBorder(lowered);
		m_inputStatus.setName("inputStatus");
		pnl2.add(m_inputStatus);
		
		JPanel pnl1=new JPanel();
		pnl1.setLayout(gl);
		pnl1.add(pnl2);
		
		m_infoRight=getLabel();
		m_infoRight.setBorder(lowered);
		m_infoRight.setName("infoRight");
        m_infoRight.setHorizontalAlignment(JLabel.RIGHT);
		pnl1.add(m_infoRight);

		m_statusText=getLabel();
		m_statusText.setBorder(lowered);
		m_statusText.setName("statusText");
		add(m_statusText);
		add(pnl1);
		
	} 
	
	private JLabel getLabel() {
		JLabel lbl=new JLabel();
		lbl.setFont(getFont());
		lbl.setForeground(Color.black);
		return lbl;
	}
	
	public void setStatusText(String str) {
		m_statusText.setText(str);
	}
	
	public void setFileStatus(String str) {
		m_fileStatus.setText(str);
	}
	
	public void setDocumentStatus(int docStat) {
		switch (docStat) {
			case EMPTY:
				m_docStatus.setText("");
				break;
			case CHANGED:
				m_docStatus.setText("CHANGED");
				break;
			case NEW:
				m_docStatus.setText("NEW");
				break;
		}
	}
	
	public void setDocumentStatus(String str) {
		m_docStatus.setText(str);
	}
	
	public void setInputStatus(String str) {
		m_inputStatus.setText(str);
	}
	
	public void setInfoText(String str) {
		
		m_infoRight.setText(str);
	}
	
	protected JComponent getStatusTextComponent() {
		return m_statusText;
	}
	
}

