/* 	InputValidator.java
 * 
 * Created on: 17-09-2002
 * Created by: Dennis Groenendijk
 * 
 * Copyright (c) 2002-2006, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 /* @#History
 * [When]		[Who]				[What]
 * 23-Sep-03		dennis@brains2.nl	Implemented localized messages
 * 01-06-2006	dennis@brains2.nl	Implemented getString(Class c)
 *
 */
package org.brains2b.swingext.mask;

import javax.swing.InputVerifier;
import javax.swing.JComponent;

/** Interface for defining Validators that can be used by MaskedField for
 *  displaying output masks. 
 *  <p>This is basically an extention to the InputVerifier
 *  class. Which provides ways to retrieve the information from a field
 *  without the display mask.
 *  <p>It also provides a way to get the error message if the verify message
 *  returns false.  
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.11 [01-06-2006]
 * @see InputVerifier
 */
public interface InputValidator  {

    /**
     * retrieves the errormessage if verify returns false.
     * @return String, the message describing the verify error, returns null if
     * there was no error.
     */
	public String getErrorMessage();
	
	
	/**
	 * retrieve the error message, localized to the default locale 
	 * if verify returns false
	 * @return String, the message describing the error in the appropriate language
	 * The message will be returned in English if the appropriate language cannot be
	 * found. Returns null if there was no error.
	 * @since Framework 0.32
	 */
	public String getLocalizedMessage();
	
	
    /**
     * gets a String as representation of the value from a InputValidator
     * <p>Implementations might differ on what you need the value for.
     * <p>If you can do with the value with the Mask just use the getText()
     * on which ever field this InputValidator is implemented on.
     * @param txt String, the Masked text of this Validator
     * @return String, the 'transformed' String you want to retrieve
     */
	public String getString(String txt);
	
	/**
     * gets a String as representation of the value from a InputValidator
     * <p>Implemenations differ for the implementations of this interface
     * and on which Class is supplied for output. Also not all requested output
     * Classes are implemented for every implementation.
     * on which ever field this InputValidator is implemented on.
     * @param txt String, the Masked text of this Validator
     * @param c Class, the type of output you want to return as a String representation
     * @return String, the 'transformed' String you want to retrieve
     */
	public String getString(String txt, Class c);
    /**
     * Just a reference to verify in javax.swing.InputVerifier
     * @see javax.swing.InputVerifier
     */
	public boolean verify(JComponent input);
}
