/* 	MaskException.java
 * 
 * Created on: 17-09-2002
 * Created by: Dennis Groenendijk
 * 
 * Copyright (c) 2003, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 /* @#History
 * [When]		[Who]				[What]
 * 23-Sep-03	dennis@brains2b.nl	Implemented localization
 *
 */
package org.brains2b.swingext.mask;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.brains2b.util.StringHelper;

/** 
 * Exception thrown by InputValidators and handled through the 
 * getErrorMessage() from org.brains2b.mask.InputValidator
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.20 [23-09-2003]
 * @see java.lang.Exception
 * @see org.brains2b.swingext.mask.InputValidator
 */
public class MaskException extends Exception {

	public final static int VALUE_TO_LARGE=1;
	
	public final static int NOT_VALID_NUMBER=100;	
	
	public final static int DOESNT_COMPLY=200;
	
	public final static int NOT_VALID_DATE=300;

	private int errorNo;
	/**
	 * Constructor for MaskException.
	 */
	public MaskException() {
		super();
	}

	public MaskException(int errorNo) {
		super();
		this.errorNo=errorNo;		
	}

	/**
	 * Constructor for MaskException.
	 * @param s String, the message for the MaskException
	 */
	public MaskException(String s) {
		super(s);
	}

    /**
     * Returns the errorNo.
     * @return int
     */
    public int getErrorNo() {
        return errorNo;
    }

	/**
     * @see java.lang.Throwable#getMessage()
     */
    public String getMessage() {
    	if (errorNo==0) {
        	return super.getMessage();
    	} else {
    		switch (errorNo) {
    			case DOESNT_COMPLY:
    				return "Value doesn't comply with mask";
    			case VALUE_TO_LARGE:
    				return "Value is too large for field";
    			case NOT_VALID_DATE:
    				return "Not a valid date";
    			case NOT_VALID_NUMBER:
    				return "Not a valid number";
    			default:
    				return "Unknown MaskException";
    		}
    	}
    }

	/**
     * @see java.lang.Throwable#getLocalizedMessage()
     */
    public String getLocalizedMessage() {
        if (errorNo==0) {
	        return super.getLocalizedMessage();
        } else {
        	ResourceBundle rb=ResourceBundle.getBundle("org.brains2b.swingext.resource.messages",Locale.getDefault());
        	final String key= "MaskException." + StringHelper.leftPad(String.valueOf(errorNo),"0",5);
        	try {
        		return rb.getString(key);
        	} catch (MissingResourceException mrex) {
        		return getMessage();
        	}
        }
    }

}
