/* 	FontHelper.java
 *	Copyright (c) 2002-2007, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.brains2b.swingext.util;

import java.awt.Font;

/**
 * Helper class to encode a Font into a String that can be decoded with
 * {@link Font#decode(String)}
 * @version 	1.0
 * @author      <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 */
public final class FontHelper {

    /**
     * Encode a Font into a String that can be decoded with {@link Font#decode(String)}
     * @param f Font, the font to encode
     * @return String, the String representation of this Font
     */
	public static String encode(Font f) {
    	 StringBuffer sb=new StringBuffer();
    	 sb.append(f.getFamily());
    	 sb.append("-");
    	 sb.append(getStyle(f.getStyle()));
    	 sb.append("-");
    	 sb.append(f.getSize());
    	 return sb.toString();
	}
	
    /**
     * get the String representation of the style constants from Font
     * @param style int, one of the constants Font.BOLD, Font.ITALIC, Font.PLAIN or the sum of those
     * @return String, the decodable String representation of the Style,
     * or PLAIN if it is not a valid value.
     */
	public static String getStyle(int style) {
		switch(style) {
			case Font.BOLD:
				return "BOLD";
			case Font.ITALIC:
				return "ITALIC";
			case Font.BOLD+Font.ITALIC:
				return "BOLDITALIC";
			case Font.PLAIN:
			default:
				return "PLAIN";
		}
	}
			

}
