/* 	PostFixFilterTest.java
 * 
 * Created on: Oct 5, 2003
 * Created by: dennis
 * 
 * Copyright (c) 2003, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package test.org.brains2b.file;

import java.io.File;

import org.brains2b.file.PostFixFilter;

import junit.framework.TestCase;

/** Unit test for org.brains2b.file.PostFixFilter
 * 
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [Oct 5, 2003]
 * @see org.brains2b.file.PostFixFilter
 */
public class PostFixFilterTest extends TestCase {

	/**
	 * Constructor for PostFixFilterTest.
	 * @param arg0
	 */
	public PostFixFilterTest(String arg0) {
		super(arg0);
	}

	public static void main(String[] args) {
		junit.swingui.TestRunner.run(PostFixFilterTest.class);
	}

	public void testInitGood() {
		PostFixFilter pff=new PostFixFilter(".xml","XML-file");
		assertEquals("XML-file",pff.getDescription());
		File test=new File("crossword.xml");
		assertTrue(pff.accept(test));
	}
	
	public void testInitIndifferent() {
		PostFixFilter pff=new PostFixFilter("test.xml","XML-file");
			
		File test=new File("crossword.xml");
		assertTrue(pff.accept(test));
	}
	
	public void testInitNull() {
		try {
			new PostFixFilter(null,"XML-file");
			assertTrue("NullPointer expected", false);
		} catch (NullPointerException npex) {
			assertTrue(true);
		}
	}
	
	public void testDescriptionMissing() {
			PostFixFilter pff=new PostFixFilter(".xml",null);
			assertEquals(".xml",pff.getDescription());
	}
	
	public void testAcceptTrue() {
		PostFixFilter pff=new PostFixFilter(".xml","XML-file");
		File test=new File("crossword.xml");
		assertTrue(pff.accept(test));
	}
	
	public void testAcceptFalse() {
		PostFixFilter pff=new PostFixFilter(".xml","XML-file");
		File test=new File("crossword.txt");
		assertTrue(!pff.accept(test));
	}
	public void testAcceptNull() {
		PostFixFilter pff=new PostFixFilter(".xml","XML-file");
		File test=null;
		assertTrue(!pff.accept(test));
	}
}
