/* 	DefaultActionTest.java
 *	Copyright (c) 2007, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: Jul 6, 2007
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package test.org.brains2b.swingext.action;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.KeyStroke;

import org.brains2b.swingext.action.DefaultAction;
import org.brains2b.swingext.gui.IconFactory;

import junit.framework.TestCase;

public class DefaultActionTest extends TestCase {
    class ActionHandler implements ActionListener {
        public void actionPerformed(ActionEvent e) {
            m_lastSource = e.getSource();
            m_lastCommand = e.getActionCommand();
        }
    }
    
    private Object m_lastSource;
    private String m_lastCommand;
    private ActionHandler m_listener = new ActionHandler();
    
    protected void setUp() throws Exception {
        super.setUp();
    }

    public void testDefaultAction() {
        DefaultAction action = new DefaultAction(m_listener,"Test");
        assertEquals("Test", action.getValue(DefaultAction.ACTION_COMMAND_KEY)); 
        
        action.putValue(DefaultAction.NAME, "Label");
        assertEquals("Label",action.getValue(DefaultAction.NAME));
        assertTrue(action.isEnabled());
        action.setEnabled(false);
        assertTrue(!action.isEnabled());
        JButton btn = new JButton(action);
        btn.doClick();
        assertNotSame(m_lastSource,btn);
        assertNotSame(m_lastCommand,"Test");
        
        action.setEnabled(true);
        btn.doClick();
        assertEquals(m_lastSource,btn);
        assertEquals(m_lastCommand,"Test");
    }
    
    public void testDefaultActionComplete() {
        KeyStroke keyStroke = KeyStroke.getKeyStroke(KeyEvent.VK_C,KeyEvent.CTRL_DOWN_MASK);
        ImageIcon icon = IconFactory.createIcon("/org/brains2b/images/icon.gif");
        
        DefaultAction action = 
            new DefaultAction(m_listener,
                    "Test",
                    "Label",
                    "Description",
                    icon,
                    keyStroke,'X');
        
        assertEquals("Test" ,action.getValue(DefaultAction.ACTION_COMMAND_KEY));
        assertEquals("Label",action.getValue(DefaultAction.NAME));
        assertEquals("Description",action.getValue(DefaultAction.SHORT_DESCRIPTION));
        assertEquals(icon,action.getValue(DefaultAction.SMALL_ICON));
        assertEquals(keyStroke,action.getValue(DefaultAction.ACCELERATOR_KEY));
        assertEquals(new Integer('X'),action.getValue(DefaultAction.MNEMONIC_KEY));
        assertNull(action.getValue(DefaultAction.LONG_DESCRIPTION));
        
        action.putValue(DefaultAction.SHORT_DESCRIPTION, null);
        assertNull(action.getValue(DefaultAction.SHORT_DESCRIPTION));
        
    }   
}
