/* 	ExtActionMapTest.java
 *	Copyright (c) 2007, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: Jul 6, 2007
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package test.org.brains2b.swingext.action;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;

import javax.swing.Action;
import javax.swing.Icon;
import javax.swing.KeyStroke;

import org.brains2b.swingext.action.DefaultAction;
import org.brains2b.swingext.action.ExtActionMap;
import org.brains2b.swingext.gui.IconFactory;

import junit.framework.TestCase;

/** Junit test for {@link ExtActionMap}
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [Jul 6, 2007]
 */
public class ExtActionMapTest extends TestCase {
    
    class ActionHandler implements ActionListener {
        public void actionPerformed(ActionEvent e) {
          
        }
    }
    
    private ActionHandler m_listener = new ActionHandler();
    
    public void testConstruction() {
        ExtActionMap map = new ExtActionMap(m_listener);
        assertEquals(m_listener,map.getListener());
        assertEquals(0, map.size());
        assertNull(map.keys());
        assertNull(map.allKeys());
    }
    
    public void testAddAction() {
        ExtActionMap map = new ExtActionMap(m_listener);
        
        Icon icn = IconFactory.createIcon("/org/brains2b/images/brains2b.org.png");
        map.addAction("Action.Test", "Label", "Description", "brains2b.org.png","alt F4", 'x');
        Action action =map.get("Action.Test");  
        assertEquals(1,map.size());
        assertEquals("Action.Test",action.getValue(Action.ACTION_COMMAND_KEY));
        assertEquals("Label",action.getValue(Action.NAME));
        assertEquals("Description",action.getValue(Action.SHORT_DESCRIPTION));
        assertEquals(icn,action.getValue(Action.SMALL_ICON));
        assertEquals(KeyStroke.getKeyStroke(KeyEvent.VK_F4, KeyEvent.ALT_DOWN_MASK),action.getValue(Action.ACCELERATOR_KEY));
        assertEquals("Label",action.getValue(Action.NAME));
        
        DefaultAction defAction = 
            new DefaultAction(m_listener,
                    "Action.Default",
                    "Label",
                    "Description",
                    null,
                    null,'X');
         map.put("Action.Default", defAction);
         action =map.get("Action.Default");
         assertEquals(2,map.size());
         assertEquals(defAction, action);
         
         assertEquals(2,map.keys().length);
         assertEquals(2,map.allKeys().length);
         assertEquals("Action.Test",map.keys()[0]);
         assertEquals("Action.Default",map.allKeys()[1]);
         
         map.remove("Action.Test");
         assertEquals(1, map.size());
         assertNull(map.get("Action.Test"));
    }
    
    public void testSystemActions() {
        ExtActionMap map = new ExtActionMap(m_listener);
        ExtActionMap.setDefaultSystemActions(map);
        assertEquals(4, map.size());
        Object[] keys = map.keys();
        assertEquals("System.exit",keys[0]);
        assertEquals("System.preference",keys[1]);
        assertEquals("Help.help",keys[2]);
        assertEquals("Help.about",keys[3]);
    }
    
    public void testParent() {
        ExtActionMap map = new ExtActionMap(m_listener);
        map.addAction("Action.Test", "Label", "Description", "brains2b.org.png","alt F4", 'x');
        ExtActionMap parent = new ExtActionMap(m_listener);
        ExtActionMap.setDefaultSystemActions(parent);
        map.setParent(parent);
        assertEquals(1, map.size());
        assertEquals(parent.get("System.exit"), map.get("System.exit"));
        assertEquals(1, map.keys().length);
        assertEquals(5, map.allKeys().length);
    }
    
    public void testBreak() {
        try {
            new ExtActionMap(null);
            assertTrue("Maps ActionListener cannot be null",false);
        } catch (IllegalArgumentException iaex) {
            assertTrue(true);
        }
        try {
            ExtActionMap map = new ExtActionMap(m_listener);
            map.addAction(null, "Label", "Description", "brains2b.org.png","alt F4", 'x');
            assertTrue("Action command key cannot be null",false);
        } catch (IllegalArgumentException iaex) {
            assertTrue(true);
        }
        
    }
}
