/* 	UserPropertiesTest.java
 *	Copyright (c) 2007, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: Jul 6, 2007
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package test.org.brains2b.swingext.conf;

import java.io.File;

import org.brains2b.swingext.conf.UserPreference;

import junit.framework.TestCase;

public class UserPreferenceTest extends TestCase {

    
    public void testStore() {
        final String testPath = UserPreference.DEFAULTPATH + "/test.properties";
        UserPreference prop = new UserPreference("test.properties");
        assertEquals(testPath,prop.getFilename());
        prop.setProperty("Appl.Font", "Dialog-10-Plain");
        prop.store();
        
        
        final File testFile = new File(System.getProperty("java.io.tmpdir"),"test.properties");
        prop = new UserPreference(testFile);
        assertEquals(testFile.getAbsolutePath(),prop.getFilename());
        prop.setProperty("Appl.Font", "Dialog-10-Plain");
        prop.store();
        assertTrue(testFile.delete());
        
        prop = new UserPreference("test.properties");
        assertEquals("Dialog-10-Plain", prop.getProperty("Appl.Font"));
        assertTrue(new File(testPath).delete());
    }

    public void testSetDefault() {
        final String testPath = UserPreference.DEFAULTPATH + "/test.properties";
        UserPreference prop = new UserPreference("test.properties");
        prop.setDefault("Appl.Font", "Dialog-10-Plain");
        prop.setDefault("Appl.Desktop.Color", "#909090");
        assertEquals("Dialog-10-Plain",prop.getProperty("Appl.Font"));
        prop.store();
        
        prop = new UserPreference("test.properties");
        assertNull(prop.getProperty("Appl.Font"));
        assertNull(prop.getProperty("Appl.Desktop.Color"));
        prop.setProperty("Appl.Font", "Courier-15-Plain");
        prop.setDefault("Appl.Desktop.Color", "#909090");
        prop.setDefault("Appl.Font", "Dialog-10-Plain");
        assertEquals("Courier-15-Plain",prop.getProperty("Appl.Font"));
        prop.store();

        prop = new UserPreference("test.properties");
        assertEquals("Courier-15-Plain",prop.getProperty("Appl.Font"));
        assertEquals("#909090",prop.getProperty("Appl.Desktop.Color"));
        assertTrue(new File(testPath).delete());
    }

}
