/* 	DateValidatorTest.java
 * 
 * Created on: 17-09-2002
 * Created by: Dennis Groenendijk
 * 
 * Copyright (c) 2002, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* @#History
 * [When]		[Who]				[What]
 * 09/19/2002	dennis@brains2b.nl	Added ConstructorThree
 * 03-07-2003	dennis@brains2b.nl	Added test nine years between 1 A.D. and 99 A.D.
 * 23-09-2003	dennis@brains2b.nl	Added test for localized message
 * 29-08-2006	dennis@brains2b.nl	Test for US MM/dd/yyyy date
 */
package test.org.brains2b.swingext.mask;

import java.util.Locale;

import javax.swing.JTextField;

import junit.framework.TestCase;

import org.brains2b.swingext.mask.DateValidator;

/** 
 * Unit test for org.brains2b.mask.DateValidator
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.13 [29-08-2006]
 */
public class DateValidatorTest extends TestCase {

	JTextField m_fld;
	DateValidator m_val;
	/**
	 * Constructor for DateValidatorTest.
	 * @param arg0
	 */
	public DateValidatorTest(String arg0) {
		super(arg0);
	}

	public static void main(String[] args) {
	
		junit.swingui.TestRunner.run(DateValidatorTest.class);
	}

	/**
	 * @see TestCase#setUp()
	 */
	public void setUp() {
		m_fld=new JTextField();
		m_val=new DateValidator(Locale.ENGLISH);
	}
	
	public void testConstructorOne() {
		DateValidator val = new DateValidator(new Locale("nl","NL"));
		m_fld.setText("03 Maart 2003");
		assertTrue(val.verify(m_fld));
		assertEquals("03-mrt-2003",m_fld.getText());	
	}		

	public void testConstructorTwo() {
		DateValidator val = new DateValidator(new Locale("nl","NL"),"dd-MM-yy");
		m_fld.setText("3-Mrt-03");
		assertTrue(val.verify(m_fld));
		assertEquals("03-03-03",m_fld.getText());	
	}		

	
	public void testConstructorThree() {
		DateValidator val = new DateValidator(new Locale("nl","NL"),"dd-MM-yyyy");
		m_fld.setText("3-Mrt-03");
		assertTrue(val.verify(m_fld));
		assertEquals("03-03-2003",m_fld.getText());	
	}
	
	public void testConstructorUS() {
		DateValidator val = new DateValidator(new Locale("en"),"MM/dd/yy");
		m_fld.setText("03/21/06");
		assertTrue(val.verify(m_fld));
		assertEquals("21-Mar-2006",val.getString(m_fld.getText()));	
	}
	
	public void testConstructorUSPlain6() {
		DateValidator val = new DateValidator(new Locale("en","US"),"MM/dd/yy");
		m_fld.setText("032106");
		assertTrue(val.verify(m_fld));
		assertEquals("21-Mar-2006",val.getString(m_fld.getText()));	
	}
	
	public void testConstructorUSPlain8() {
		DateValidator val = new DateValidator(new Locale("en","US"),"MM/dd/yy");
		m_fld.setText("03211906");
		assertTrue(val.verify(m_fld));
		assertEquals("21-Mar-2006",val.getString(m_fld.getText()));	
	}

	/*
	 * Test for boolean verify(JComponent)
	 */
	public void testOne() {
		m_fld.setText("030303");
		assertTrue(m_val.verify(m_fld));
		assertEquals("03-Mar-2003",m_fld.getText());		
	}
	
	public void testOneA() {
		m_fld.setText("010101");
		assertTrue(m_val.verify(m_fld));
		assertEquals("01-Jan-2001",m_fld.getText());		
	}
	
	public void testOneB() {
		m_fld.setText("121212");
		assertTrue(m_val.verify(m_fld));
		assertEquals("12-Dec-2012",m_fld.getText());		
	}
	
	public void testTwo() {
		m_fld.setText("13-03-03");
		assertTrue(m_val.verify(m_fld));
		assertEquals("13-Mar-2003",m_fld.getText());		
	}

	public void testThree() {
		m_fld.setText("03 March 2013");
		assertTrue(m_val.verify(m_fld));
		assertEquals("03-Mar-2013",m_fld.getText());		
	}
	
	public void testFour() {
		m_fld.setText("03 Apr 2003");
		assertTrue(m_val.verify(m_fld));
		assertEquals("03-Apr-2003",m_fld.getText());		
	}
	
	public void testFive() {
		m_fld.setText("3/9/23");
		assertTrue(m_val.verify(m_fld));
		assertEquals("03-Sep-2023",m_fld.getText());		
	}
	
	public void testSix() {
		m_fld.setText("0303");
		assertTrue(!m_val.verify(m_fld));
		assertEquals("0303",m_fld.getText());		
	}
	
	public void testSeven() {
		m_fld.setText(null);
		assertTrue(m_val.verify(m_fld));
		assertEquals("",m_fld.getText());		
	}
	
	public void testEight() {
		m_fld.setText("03.bla.03");
		assertTrue(!m_val.verify(m_fld));
		assertEquals("03.bla.03",m_fld.getText());		
	}

	public void testNine() {
		m_fld.setText("01-01-0001");
		assertTrue(m_val.verify(m_fld));
		assertEquals("01-Jan-0001",m_fld.getText());		
	}

	public void testNineA() {
		m_fld.setText("01-01-1901");
		assertTrue(m_val.verify(m_fld));
		assertEquals("01-Jan-1901",m_fld.getText());		
	}
	
	public void testNineB() {
		m_fld.setText("01-01-0101");
		assertTrue(m_val.verify(m_fld));
		assertEquals("01-Jan-0101",m_fld.getText());		
	}
	
	public void testNineC() {
		m_fld.setText("01-11-2004");
		assertTrue(m_val.verify(m_fld));
		assertEquals("01-Nov-2004",m_fld.getText());		
	}
	
	public void testNineD() {
		m_fld.setText("01-11-04");
		assertTrue(m_val.verify(m_fld));
		assertEquals("01-Nov-2004",m_fld.getText());		
	}

	public void testAbsoluteValidDate() {
		m_fld.setText("290203");
		assertTrue(!m_val.verify(m_fld));
		assertEquals("Not a valid date",m_val.getErrorMessage());		
		
	}
	
	public void testAbsoluteValidDate2() {
		m_fld.setText("320103");
		assertTrue(!m_val.verify(m_fld));
		assertEquals("Not a valid date",m_val.getErrorMessage());		
		
	}
	
	public void testAbsoluteValidDate3() {
		m_fld.setText("291303");
		assertTrue(!m_val.verify(m_fld));
		assertEquals("Not a valid date",m_val.getErrorMessage());		
		
	}
	
	public void testLocale() {
		m_fld.setText("29-jan-2003");
		assertTrue(m_val.verify(m_fld));
		assertEquals("29-jan-2003",m_fld.getText());
	}
	
	public void testLocaleMessage() {
		Locale.setDefault(new Locale("nl","NL"));
		m_fld.setText("291303");
		assertTrue(!m_val.verify(m_fld));
		assertEquals("Geen geldige datum",m_val.getLocalizedMessage());		
		
	}
	
	public void testAsteriks() {
		m_fld.setText("29*909909");
		assertTrue(!m_val.verify(m_fld));
		m_fld.setText("29-jan-2003");
		assertEquals("29-jan-2003",m_fld.getText());
	}
}
