/* 	NumberValidatorTest.java
 * 
 * 	Created on: 17-09-2002
 * 	Created by: Dennis Groenendijk
 * 
 * Copyright (c) 2002,2003, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 /* @#History
 * [When]			[Who]							[What]
 * 12-02-2003	dennis@brains2b.nl	Added tests
 * 23-09-2003	dennis@brains2b.nl	Added tests for getString()
 * 									Added test for localized message
 * 01-06-2006	dennis@brains2.nl	Extra test for changes to recognizing masked String
 */
package test.org.brains2b.swingext.mask;

import java.util.Locale;

import javax.swing.JTextField;

import junit.framework.TestCase;

import org.brains2b.swingext.mask.NumberValidator;

/** 
 * Unit test for org.brains2b.mask.NumberValidator
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.12 [23-09-2003]
 * @see org.brains2b.swingext.mask.NumberValidator
 */
public class NumberValidatorTest extends TestCase {

	JTextField m_fld;
	NumberValidator m_num;

	/**
	 * Constructor for NumberValidatorTest.
	 * @param arg0
	 */
	public NumberValidatorTest(String arg0) {
		super(arg0);
	}

	public static void main(String[] args) {
		junit.swingui.TestRunner.run(NumberValidatorTest.class);
	}

	/**
	 * @see TestCase#setUp()
	 */
	public void setUp() {
		Locale.setDefault(new Locale("nl","NL"));
		m_fld=new JTextField();
		m_num=new NumberValidator();
	}

	public void testOne() {
		m_fld.setText("100");
		assertTrue(m_num.verify(m_fld));		
		assertEquals("100,00",m_fld.getText());
	}
	
	public void testTwo() {
		m_fld.setText("100,00");
		assertTrue(m_num.verify(m_fld));		
		assertEquals("100,00",m_fld.getText());
	}
	
	public void testThree() {
		m_fld.setText("100,0");
		assertTrue(m_num.verify(m_fld));		
		assertEquals("100,00",m_fld.getText());
	}
	
	public void testFour() {
		m_fld.setText("1000,0");
		assertTrue(m_num.verify(m_fld));		
		assertEquals("1.000,00",m_fld.getText());
	}

	public void testFive() {
		m_fld.setText("1.000,00");
		assertTrue(m_num.verify(m_fld));		
		assertEquals("1.000,00",m_fld.getText());
	}
	
	public void testSix() {
		m_fld.setText(",5");
		assertTrue(m_num.verify(m_fld));		
		assertEquals("0,50",m_fld.getText());
	}
	
	public void testSeven() {
		m_fld.setText("foo");
		assertTrue(!m_num.verify(m_fld));
		assertEquals("foo",m_fld.getText());
	}
	
	public void testEight() {
		m_fld.setText(null);
		assertTrue(m_num.verify(m_fld));
		assertEquals("",m_fld.getText());
	}

	public void testNine() {
		m_fld.setText("0");
		assertTrue(m_num.verify(m_fld));
		assertEquals("0,00",m_fld.getText());
	}
	
	public void testTen() {
		NumberValidator num=new NumberValidator("###.###.##9");
		m_fld.setText("0");
		assertTrue(num.verify(m_fld));
		assertEquals("0",m_fld.getText());
	}
	
	public void testTwelve() {
		NumberValidator num=new NumberValidator("####.###.##9");
		m_fld.setText("2003010113");
		assertTrue(num.verify(m_fld));
		assertEquals("2003.010.113",m_fld.getText());
	}
	
	public void testThirteen() {
		NumberValidator num=new NumberValidator("#### ### ##9");
		m_fld.setText("20030");
		assertTrue(num.verify(m_fld));
		assertEquals("20 030",m_fld.getText());
	}
	
	public void testFourteen() {
		NumberValidator num=new NumberValidator("#9,99");
		m_fld.setText(",05");
		assertTrue(num.verify(m_fld));
		assertEquals("0,05",m_fld.getText());
	}
	
	public void testFifteen() {
		NumberValidator num=new NumberValidator("#9,99");
		m_fld.setText("-,05");
		assertTrue(num.verify(m_fld));
		assertEquals("-0,05",m_fld.getText());
	}
	
	public void testSixteen() {
		NumberValidator num=new NumberValidator("#9,99");
		m_fld.setText(",05-");
		assertTrue(num.verify(m_fld));
		assertEquals("-0,05",m_fld.getText());
	}
	
	public void testSixteenB() {
		NumberValidator num=new NumberValidator("#9,99");
		m_fld.setText("0,01294");
		assertTrue(num.verify(m_fld));
		assertEquals("0,01",m_fld.getText());
	}
	
	public void testSeventeen() {
		NumberValidator num=new NumberValidator("#9,99");
		m_fld.setText("0-");
		assertTrue(num.verify(m_fld));
		assertEquals("0,00",m_fld.getText());
	}
	
	public void testEighteen() {
		NumberValidator num=new NumberValidator("9");
		m_fld.setText("0-");
		assertTrue(num.verify(m_fld));
		assertEquals("0",m_fld.getText());
	}
	
	public void testNineteen() {
		NumberValidator num=new NumberValidator("##,##");
		m_fld.setText("0");
		assertTrue(num.verify(m_fld));
		assertEquals("0",m_fld.getText());
	}
	
	public void testEleven() {
		m_fld.setText("-5.00");
		assertTrue(m_num.verify(m_fld));
		assertEquals("-5,00",m_fld.getText());
	}
	

	public void testMakeOne() {
		assertEquals("1,00",m_num.makeString("100"));
	} 
	
	public void testMakeTwo() {
		assertEquals("-1,00",m_num.makeString("-100"));
	}
	
	public void testMarkThree() {
		NumberValidator num=new NumberValidator("### 999,99");
		assertEquals("10 000,00", num.makeString("1000000"));
	} 	
	
	public void testMakeFour() {
		assertEquals("0,90",m_num.makeString("90"));
	} 	
	
	public void testMarkFive() {
		NumberValidator num=new NumberValidator("#9");
		assertEquals("79", num.makeString("79"));
	} 	

	public void testMakeSix() {
		NumberValidator num=new NumberValidator("#9,99");
		assertEquals("-0,09",num.makeString("-9"));
	} 	
	
	public void testMakeSeven() {
		NumberValidator num=new NumberValidator("##,##");
		assertEquals(null,num.makeString("0"));
	}
	
	public void testMakeEight() {
		NumberValidator num=new NumberValidator("##,##");
		assertNull(num.makeString("-0"));
	}
	
	public void testMakeNine() {
		NumberValidator num=new NumberValidator("#9");
		assertEquals("0",num.makeString("0"));
	}
	
	public void testLargeNumber1() {
		NumberValidator num=new NumberValidator("### ### ##9,99");
		m_fld.setText("100000000");
		assertTrue(num.verify(m_fld));
		assertEquals("100 000 000,00",m_fld.getText());
	}
	
	public void testLargeNumber2() {
		NumberValidator num=new NumberValidator("### ##9");
		m_fld.setText("1000000");
		assertTrue(!num.verify(m_fld));
		
	}
	
	public void testGetString1() {
		NumberValidator num=new NumberValidator("### ##9,99");
		assertEquals("10000005",num.getString("100 000,05"));
	}
	
	public void testGetString2() {
		NumberValidator num=new NumberValidator("### ##9,99");
		assertEquals("-12345678",num.getString("-123 456,78"));
	}
	
	public void testGetString3() {
		NumberValidator num=new NumberValidator("### ##9,99");
		assertEquals("0",num.getString("0,00"));
	}
	
	public void testGetString4() {
		NumberValidator num=new NumberValidator("### ##9,99");
		assertEquals("5",num.getString("0,05"));
	}
	
	public void testGetString5() {
		NumberValidator num=new NumberValidator("### ##9,99");
		assertNull(num.getString(null));
	}
	
	public void testLocaleMessage() {
		Locale.setDefault(new Locale("nl","NL"));
		NumberValidator num=new NumberValidator("### ##9");
		m_fld.setText("1000000");
		assertTrue(!num.verify(m_fld));
		assertEquals("Waarde is te groot voor dit veld", num.getLocalizedMessage());
		
	}
	
	public void testTimeMask() {
		NumberValidator num=new NumberValidator("99:99");
		assertEquals("700",num.getString("07:00"));
		m_fld.setText("830");
		assertTrue(num.verify(m_fld));
		assertEquals("08:30",m_fld.getText());
		m_fld.setText("1211");
		assertTrue(num.verify(m_fld));
		assertEquals("12:11",m_fld.getText());
		m_fld.setText("50");
		assertTrue(num.verify(m_fld));
		assertEquals("00:50",m_fld.getText());
		m_fld.setText("11150");
		assertTrue(!num.verify(m_fld));
	}
	
	public void testHash1() {
	    NumberValidator num=new NumberValidator("### ###,##");
	    m_fld.setText("5");
	    assertTrue(num.verify(m_fld));
	    assertEquals("0,05",num.makeString("5"));
	}
	
	public void testHash2() {
	    NumberValidator num=new NumberValidator("### ###,##");
	    m_fld.setText("10");
	    assertTrue(num.verify(m_fld));
	    assertEquals("0,10",num.makeString("10"));
	}
	
	public void testHash3() {
	    NumberValidator num=new NumberValidator("### ###,##");
	    m_fld.setText("100");
	    assertTrue(num.verify(m_fld));
	    assertEquals("1,00",num.makeString("100"));
	}
	
	
	public void testMaskedString1() {
		NumberValidator num=new NumberValidator("### ##9,99");
	    m_fld.setText("1,00");
	    assertTrue(num.verify(m_fld));
	    assertEquals("10,00",num.makeString("10,00"));
	}
}
