/* 	TextValidatorTest.java
 * 
 * Created on: 17-09-2002
 * Created by: Dennis Groenendijk
 * 
 * Copyright (c) 2002, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* @#History
 * [When]		[Who]				[What]
 * 23-09-2003	dennis@brains2b.nl	Added test for localized message
 * 17-04-2005	dennis@brains2b.nl	Added code for right align
 */
package test.org.brains2b.swingext.mask;

import java.util.Locale;

import javax.swing.JTextField;

import junit.framework.TestCase;

import org.brains2b.swingext.mask.TextValidator;

/** 
 * Unit test for  org.brains2b.mask.TextValidator
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.11 [05-08-2003]
 * @see org.brains2b.swingext.mask.TextValidator
 */
public class TextValidatorTest extends TestCase {

	JTextField m_fld;
	TextValidator m_tex;

	/**
	 * Constructor for NumberValidatorTest.
	 * @param arg0
	 */
	public TextValidatorTest(String arg0) {
		super(arg0);
	}

	public static void main(String[] args) {
		junit.swingui.TestRunner.run(TextValidatorTest.class);
	}

	/**
	 * @see TestCase#setUp()
	 */
	public void setUp() {
		m_tex=new TextValidator("@@-@@-@@");
        m_fld=new JTextField();
	}

	public void testOne() {
		m_fld.setText("XH-PH-10");
		assertTrue(m_tex.verify(m_fld));		
		assertEquals("XH-PH-10",m_fld.getText());
	}
	
	public void testTwo() {
		m_fld.setText("XHPH10");
		assertTrue(m_tex.verify(m_fld));		
		assertEquals("XH-PH-10",m_fld.getText());
	}
	
	public void testThree() {
		m_fld.setText("XHPH");
		assertTrue(!m_tex.verify(m_fld));		
		assertEquals("XHPH",m_fld.getText());
	}
	
	public void testFour() {
		m_fld.setText("XH-PH10");
		assertTrue(m_tex.verify(m_fld));		
		assertEquals("XH-PH-10",m_fld.getText());
	}

	public void testFive() {
		m_fld.setText("XH PH 10");
		assertTrue(!m_tex.verify(m_fld));		
		assertEquals("XH PH 10",m_fld.getText());
	}	
	public void testSix() {
		m_fld.setText(null);
		assertTrue(m_tex.verify(m_fld));		
		assertEquals("",m_fld.getText());
	}
	
	public void testSeven() {
		m_tex=new TextValidator("AA 9999");
		m_fld.setText("NL 1024");
		assertTrue(m_tex.verify(m_fld));		
		assertEquals("NL 1024",m_fld.getText());
	}
	
	public void testEight() {
		m_tex=new TextValidator("AA 9999");
		m_fld.setText("NL1024");
		assertTrue(m_tex.verify(m_fld));		
		assertEquals("NL 1024",m_fld.getText());
	}
	
	public void testNine() {
		m_tex=new TextValidator("AA 9999");
		m_fld.setText("N1 1024");
		assertTrue(!m_tex.verify(m_fld));		
		assertEquals("N1 1024",m_fld.getText());
	}
	
	public void testTen() {
		m_tex=new TextValidator("AA 9999");
		m_fld.setText("NA 102B");
		assertTrue(!m_tex.verify(m_fld));		
		assertEquals("NA 102B",m_fld.getText());
	}
	
	public void testEleven() {
		m_tex=new TextValidator("AA 9999");
		m_fld.setText("NA_1024");
		assertTrue(!m_tex.verify(m_fld));		
		assertEquals("NA_1024",m_fld.getText());
	}
	
	public void testTwelve() {
		m_tex=new TextValidator("@@@@");
		m_fld.setText("N1024");
		assertTrue(!m_tex.verify(m_fld));		
		assertEquals("N1024",m_fld.getText());
	}
	
	public void testThirteen() {
		m_tex=new TextValidator("@@@@");
		m_fld.setText("N1024X");
		assertTrue(!m_tex.verify(m_fld));		
		assertEquals("N1024X",m_fld.getText());
	}
	
	public void testFourteen() {
		m_tex=new TextValidator("@@@@ @@? ???");
		m_fld.setText("123456");
		assertTrue(m_tex.verify(m_fld));		
		assertEquals("1234 56 ",m_fld.getText());
	}
	
	
	public void testLocaleMessage() {
		Locale.setDefault(new Locale("nl","NL"));
		m_tex=new TextValidator("@@@@");
		m_fld.setText("N1024X");
		assertTrue(!m_tex.verify(m_fld));		
		assertEquals("Waarde past niet in het masker",m_tex.getLocalizedMessage());
	}
	
	public void testRightAlign() {
	    m_tex=new TextValidator(">?9:99");
		m_fld.setText("123");
		assertTrue(m_tex.verify(m_fld));		
		assertEquals(" 1:23",m_fld.getText());
	}
	
	public void testRightAlignOnly() {
	    m_tex=new TextValidator(">");
		m_fld.setText("123");
		assertTrue(!m_tex.verify(m_fld));		
		assertEquals("Value doesn't comply with mask",m_tex.getErrorMessage());
	}
    
    public void testQuestionBeforeFixed() {
        m_tex=new TextValidator("?@-NL-999");
        m_fld.setText("CA123");
        assertTrue(m_tex.verify(m_fld));
        assertEquals("CA-NL-123",m_fld.getText());
        //m_fld.setText("A123");
        //assertTrue(m_tex.verify(m_fld));
    }
}
